@@ -9,7 +9,7 @@
 """
 
 __author__ = "Ryan McGrath <ryan@venodesigns.net>"
-__version__ = "2.4.0"
+__version__ = "2.5.0"
 
 import urllib
 import re
@@ -165,6 +165,11 @@ class Twython(object):
             raise TwythonError('Method must be of GET or POST')
 
         params = params or {}
+        # requests doesn't like items that can't be converted to unicode,
+        # so let's be nice and do that for the user
+        for k, v in params.items():
+            if isinstance(v, (int, bool)):
+                params[k] = u'%s' % v
 
         func = getattr(self.client, method)
         if method == 'get':
@@ -185,15 +190,14 @@ class Twython(object):
             'content': content,
         }
 
-
         #  wrap the json loads in a try, and defer an error
         #  why? twitter will return invalid json with an error code in the headers
         json_error = False
         try:
             content = simplejson.loads(content)
         except ValueError:
-            json_error= True
-            content= {}
+            json_error = True
+            content = {}
 
         if response.status_code > 304:
             # If there is no error message, use a default.
@@ -210,8 +214,8 @@ class Twython(object):
                                 error_code=response.status_code,
                                 retry_after=response.headers.get('retry-after'))
 
-        # if we have a json error here , then it's not an official TwitterAPI error
-        if json_error:
+        # if we have a json error here, then it's not an official TwitterAPI error
+        if json_error and not response.status_code in (200, 201, 202):
             raise TwythonError('Response was not valid JSON, unable to decode.')
 
         return content
@@ -223,7 +227,7 @@ class Twython(object):
     we haven't gotten around to putting it in Twython yet. :)
     '''
 
-    def request(self, endpoint, method='GET', params=None, files=None, version=1):
+    def request(self, endpoint, method='GET', params=None, files=None, version='1.1'):
         # In case they want to pass a full Twitter URL
         # i.e. https://search.twitter.com/
         if endpoint.startswith('http://') or endpoint.startswith('https://'):
@@ -235,10 +239,10 @@ class Twython(object):
 
         return content
 
-    def get(self, endpoint, params=None, version=1):
+    def get(self, endpoint, params=None, version='1.1'):
         return self.request(endpoint, params=params, version=version)
 
-    def post(self, endpoint, params=None, files=None, version=1):
+    def post(self, endpoint, params=None, files=None, version='1.1'):
         return self.request(endpoint, 'POST', params=params, files=files, version=version)
 
     # End Dynamic Request Methods
@@ -365,7 +369,7 @@ class Twython(object):
             e.g x.search(q='jjndf', page='2')
         """
 
-        return self.get('https://search.twitter.com/search.json', params=kwargs)
+        return self.get('https://api.twitter.com/1.1/search/tweets.json', params=kwargs)
 
     def searchGen(self, search_query, **kwargs):
         """ Returns a generator of tweets that match a specified query.
@@ -379,7 +383,7 @@ class Twython(object):
                     print result
         """
         kwargs['q'] = search_query
-        content = self.get('https://search.twitter.com/search.json', params=kwargs)
+        content = self.get('https://api.twitter.com/1.1/search/tweets.json', params=kwargs)
 
         if not content['results']:
             raise StopIteration
@@ -400,8 +404,24 @@ class Twython(object):
         for tweet in self.searchGen(search_query, **kwargs):
             yield tweet
 
+    def bulkUserLookup(self, **kwargs):
+        """Stub for a method that has been deprecated, kept for now to raise errors
+            properly if people are relying on this (which they are...).
+        """
+        warnings.warn(
+            "This function has been deprecated. Please migrate to .lookupUser() - params should be the same.",
+            DeprecationWarning,
+            stacklevel=2
+        )
+
     # The following methods are apart from the other Account methods,
     # because they rely on a whole multipart-data posting function set.
+
+    ## Media Uploading functions ##############################################
+
+    def _media_update(self, url, file_, **params):
+        return self.post(url, params=params, files=file_)
+
     def updateProfileBackgroundImage(self, file_, tile=True, version=1):
         """Updates the authenticating user's profile background image.
 
@@ -417,16 +437,6 @@ class Twython(object):
                                   {'image': (file_, open(file_, 'rb'))},
                                   **{'tile': tile})
 
-    def bulkUserLookup(self, **kwargs):
-        """Stub for a method that has been deprecated, kept for now to raise errors
-            properly if people are relying on this (which they are...).
-        """
-        warnings.warn(
-            "This function has been deprecated. Please migrate to .lookupUser() - params should be the same.",
-            DeprecationWarning,
-            stacklevel=2
-        )
-
     def updateProfileImage(self, file_, version=1):
         """Updates the authenticating user's profile image (avatar).
 
@@ -438,7 +448,7 @@ class Twython(object):
         return self._media_update(url,
                                   {'image': (file_, open(file_, 'rb'))})
 
-    def updateStatusWithMedia(self, file_, version=1, **params):
+    def updateStatusWithMedia(self, file_, version='1.1', **params):
         """Updates the users status with media
 
             :param file_: (required) A string to the location of the file
@@ -453,10 +463,24 @@ class Twython(object):
                                   {'media': (file_, open(file_, 'rb'))},
                                   **params)
 
-    def _media_update(self, url, file_, **params):
-        return self.post(url, params=params, files=file_)
+    def updateProfileBannerImage(self, file_, version=1, **params):
+        """Updates the users profile banner
 
-    def getProfileImageUrl(self, username, size='normal', version=1):
+            :param file_: (required) A string to the location of the file
+            :param version: (optional) A number, default 1 because that's the
+                            only API version Twitter has now
+
+            **params - You may pass items that are taken in this doc
+                       (https://dev.twitter.com/docs/api/1/post/account/update_profile_banner)
+        """
+        url = 'https://api.twitter.com/%d/account/update_profile_banner.json' % version
+        return self._media_update(url,
+                                  {'banner': (file_, open(file_, 'rb'))},
+                                  **params)
+
+    ###########################################################################
+
+    def getProfileImageUrl(self, username, size='normal', version='1.1'):
         """Gets the URL for the user's profile image.
 
             :param username: (required) Username, self explanatory.
